@@ -3,7 +3,7 @@
 /*
  * Copyright (c) 2003 Andre Lerche <a.lerche@gmx.net>
  * Copyright (c) 2003 Benedikt Meurer <benedikt.meurer@unix-ag.uni-siegen.de>
- * Copyright (c) 2007 Mike Massonnet <mmassonnet@xfce.org>
+ * Copyright (c) 2007, 2008 Mike Massonnet <mmassonnet@xfce.org>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -78,9 +78,9 @@ typedef struct
     gboolean            show_size;
     gboolean            show_progress_bar;
     gboolean            hide_button;
+    gboolean            show_name;
     gchar              *name;
     gchar              *path;
-    gchar              *filemanager;
 
     GtkWidget          *ebox;
     GtkWidget          *box;
@@ -100,20 +100,26 @@ static GtkTooltips *tooltips = NULL;
 
 // all functions {{{
 
-static inline void
+static void
 fsguard_refresh_button (FsGuard *fsguard)
 {
     /* Refresh the checkbox state as seen in the dialog */
-    if (GTK_IS_WIDGET (fsguard->cb_hide_button)
-        && fsguard->hide_button == TRUE && *(fsguard->name) == '\0'
-        && !fsguard->show_size && !fsguard->show_progress_bar)
-        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (fsguard->cb_hide_button), FALSE);
+    if (fsguard->hide_button == TRUE && (*(fsguard->name) == '\0' || !fsguard->show_name)
+        && !fsguard->show_size && !fsguard->show_progress_bar) {
+        DBG ("Show the button back");
+        if (G_LIKELY (GTK_IS_WIDGET (fsguard->cb_hide_button)))
+            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (fsguard->cb_hide_button), TRUE);
+        else {
+            gtk_widget_show (fsguard->btn_panel);
+            fsguard->hide_button = FALSE;
+        }
+    }
 }
 
 static void
 fsguard_refresh_name (FsGuard *fsguard)
 {
-    if (*(fsguard->name) != '\0') {
+    if (*(fsguard->name) != '\0' && fsguard->show_name) {
         gtk_label_set_text (GTK_LABEL(fsguard->lab_name), fsguard->name);
         gtk_widget_show (fsguard->lab_name);
     } else {
@@ -125,36 +131,47 @@ fsguard_refresh_name (FsGuard *fsguard)
 static void
 fsguard_set_icon (FsGuard *fsguard, gint id)
 {
+    GtkIconTheme       *icon_theme;
     GdkPixbuf          *pixbuf;
+    GdkPixbuf          *scaled;
     gint                size;
 
     if (id == fsguard->icon_id)
         return;
 
     fsguard->icon_id = id;
-    size = xfce_panel_plugin_get_size (fsguard->plugin);
-    size = size - 2 - (2 * MAX (fsguard->btn_panel->style->xthickness,
-                                fsguard->btn_panel->style->ythickness));
+	size = xfce_panel_plugin_get_size (fsguard->plugin);
+    size -= 2 + 2 * MAX (fsguard->btn_panel->style->xthickness,
+                         fsguard->btn_panel->style->ythickness);
 
-    switch (id) {
-      default:
-      case ICON_NORMAL:
-        pixbuf = xfce_themed_icon_load ("xfce4-fsguard-plugin", size);
-        break;
-      case ICON_WARNING:
-        pixbuf = xfce_themed_icon_load ("xfce4-fsguard-plugin-warning", size);
-        break;
-      case ICON_URGENT:
-        pixbuf = xfce_themed_icon_load ("xfce4-fsguard-plugin-urgent", size);
-        break;
+    icon_theme = gtk_icon_theme_get_default ();
+    if (id == ICON_URGENT) {
+        pixbuf = gtk_icon_theme_load_icon (icon_theme, "xfce4-fsguard-plugin-urgent", size, 0, NULL);
+    } else if (id == ICON_WARNING) {
+        pixbuf = gtk_icon_theme_load_icon (icon_theme, "xfce4-fsguard-plugin-warning", size, 0, NULL);
+    } else {
+        pixbuf = gtk_icon_theme_load_icon (icon_theme, "xfce4-fsguard-plugin", size, 0, NULL);
     }
 
-    gtk_widget_set_sensitive (fsguard->icon_panel, id != ICON_INSENSITIVE);
+    if (G_UNLIKELY (NULL == pixbuf)) {
+        pixbuf = gtk_icon_theme_load_icon (icon_theme, GTK_STOCK_HARDDISK, size, 0, NULL);
+    }
+
+    if (G_UNLIKELY (NULL == pixbuf)) {
+        gtk_image_clear (GTK_IMAGE (fsguard->icon_panel));
+        return;
+    }
+
+    scaled = gdk_pixbuf_scale_simple (pixbuf, size, size, GDK_INTERP_BILINEAR);
+    g_object_unref (G_OBJECT (pixbuf));
+    pixbuf = scaled;
+
     gtk_image_set_from_pixbuf (GTK_IMAGE (fsguard->icon_panel), pixbuf);
+    gtk_widget_set_sensitive (fsguard->icon_panel, id != ICON_INSENSITIVE);
     g_object_unref (G_OBJECT (pixbuf));
 }
 
-static inline void
+static void
 fsguard_refresh_icon (FsGuard *fsguard)
 {
     gint icon_id = fsguard->icon_id;
@@ -193,87 +210,111 @@ fsguard_refresh_monitor (FsGuard *fsguard)
                             &color);
 }
 
+static inline gboolean
+__open_mnt (gchar *command, gchar *path)
+{
+    gboolean res;
+    gchar *cmd;
+    gchar *path_quoted;
+    path_quoted = g_shell_quote (path);
+    cmd = g_strdup_printf ("%s %s", command, path_quoted);
+    res = xfce_exec (cmd, FALSE, FALSE, NULL);
+    g_free (path_quoted);
+    g_free (cmd);
+    return res;
+}
+
 static void
 fsguard_open_mnt (GtkWidget *widget, FsGuard *fsguard)
 {
-    GString *cmd;
-    if (strlen(fsguard->filemanager) == 0) {
-        return;
-    }
-    cmd = g_string_new (fsguard->filemanager);
-    if (fsguard->path != NULL && (strcmp(fsguard->path, ""))) {
-        g_string_append (cmd, " ");
-        g_string_append (cmd, fsguard->path);
-    }
-    xfce_exec (cmd->str, FALSE, FALSE, NULL);
-    g_string_free (cmd, TRUE);
+    if (fsguard->path == NULL || fsguard->path[0] == '\0')
+      return;
+
+    if (__open_mnt ("exo-open", fsguard->path))
+      return;
+    if (__open_mnt ("Thunar", fsguard->path))
+      return;
+    if (__open_mnt ("xdg-open", fsguard->path))
+      return;
+
+    GtkWidget *dialog;
+    dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_NO_SEPARATOR, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
+                                     "Free Space Checker", NULL);
+    gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+                                              _("Unable to find an appropriate application to open the mount point"),
+                                              NULL);
 }
 
 static gboolean
 fsguard_check_fs (FsGuard *fsguard)
 {
-    float               size = 0;
+    float               free = 0;
     float               total = 0;
     float               freeblocks = 0;
     float               totalblocks = 0;
-    long                blocksize;
+    long                blocksize = 0;
     int                 err;
     gchar               msg_size[100], msg_total_size[100], msg[100];
     gint                icon_id = ICON_INSENSITIVE;
     static struct statfs fsd;
 
     err = statfs (fsguard->path, &fsd);
-    
+
     if (err != -1) {
         blocksize       = fsd.f_bsize;
         freeblocks      = fsd.f_bavail;
         totalblocks     = fsd.f_blocks;
-        size            = (freeblocks * blocksize) / 1048576;
+        free            = (freeblocks * blocksize) / 1048576;
         total           = (totalblocks * blocksize) / 1048576;
 
-        if (total > 1024) {
-            g_snprintf (msg_total_size, sizeof (msg_total_size), _("%.2f GB"), total/1024);
-        } else {
-            g_snprintf (msg_total_size, sizeof (msg_total_size), _("%.2f MB"), total);
-        }
-        if (size > 1024) {
-            g_snprintf (msg_size, sizeof (msg_size), _("%.2f GB"), size/1024);
-        } else {
-            g_snprintf (msg_size, sizeof (msg_size), _("%.2f MB"), size);
-        }
-        gtk_label_set_text (GTK_LABEL(fsguard->lab_size), msg_size);
-        gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR(fsguard->progress_bar), size / total);
-
-        if (size <= fsguard->limit_urgent) {
-            icon_id = ICON_URGENT;
-	    if (!fsguard->seen) {
-                if (fsguard->name != NULL && (strcmp(fsguard->name,"")) && (strcmp(fsguard->path, fsguard->name))) {
-                    xfce_warn (_("Only %s space left on %s (%s)!"), msg_size, fsguard->path, fsguard->name);
-                } else {
-                    xfce_warn (_("Only %s space left on %s!"), msg_size, fsguard->path);
-		}
-		fsguard->seen = TRUE;
-	    }
-        } else if (size >= fsguard->limit_urgent && size <= fsguard->limit_warning) {
+        if (free > (total * fsguard->limit_warning / 100)) {
+            icon_id = ICON_NORMAL;
+        } else if (free > (total * fsguard->limit_urgent / 100) && free <= (total * fsguard->limit_warning / 100)) {
             icon_id = ICON_WARNING;
         } else {
-            icon_id = ICON_NORMAL;
+            icon_id = ICON_URGENT;
         }
-
-        if (fsguard->name != NULL && (strcmp(fsguard->name,"")) && (strcmp(fsguard->path, fsguard->name))) {
-            g_snprintf (msg, sizeof (msg), _("%s/%s space left on %s (%s)"), msg_size, msg_total_size, fsguard->path, fsguard->name);
-        } else if (fsguard->path != NULL && (strcmp(fsguard->path, ""))) {
-            g_snprintf (msg, sizeof (msg), _("%s/%s space left on %s"), msg_size, msg_total_size, fsguard->path);
-        } 
-    } else {
-        gtk_label_set_text (GTK_LABEL(fsguard->lab_size), "0.0 MB");
-        gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR(fsguard->progress_bar), 0.0);
-        g_snprintf (msg, sizeof (msg), _("could not check mountpoint %s, please check your config"), fsguard->path);
     }
-    
+
+    /* msg_total_size, msg_size */
+    if (total > 1024) {
+        g_snprintf (msg_total_size, sizeof(msg_total_size), _("%.2f GB"), total / 1024);
+        g_snprintf (msg_size, sizeof (msg_size), _("%.2f GB"), free / 1024);
+        g_snprintf (msg, sizeof (msg),
+                    (*(fsguard->name) != '\0' && strcmp(fsguard->path, fsguard->name)) ?
+                    _("%s/%s space left on %s (%s)") : _("%s/%s space left on %s"),
+                    msg_size, msg_total_size, fsguard->path, fsguard->name);
+    } else {
+        g_snprintf (msg_total_size, sizeof (msg_total_size), _("%.0f MB"), total);
+        g_snprintf (msg_size, sizeof (msg_size), _("%.0f MB"), free);
+        g_snprintf (msg, sizeof (msg),
+                    _("could not check mountpoint %s, please check your config"),
+                    fsguard->path);
+    }
+
+    if (fsguard->show_size) {
+        gtk_label_set_text (GTK_LABEL(fsguard->lab_size),
+                            msg_size);
+    }
+    if (fsguard->show_progress_bar) {
+        gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR(fsguard->progress_bar),
+                                       (total > 0 ) ? 1.0 - (free / total) : 0.0);
+        fsguard_refresh_monitor (fsguard);
+    }
+
     gtk_tooltips_set_tip (tooltips, fsguard->ebox, msg, NULL);
     fsguard_set_icon (fsguard, icon_id);
-    fsguard_refresh_monitor (fsguard);
+
+    if (err != -1 && !fsguard->seen && icon_id == ICON_URGENT) {
+        fsguard->seen = TRUE;
+        if (*(fsguard->name) != '\0' && strcmp(fsguard->path, fsguard->name)) {
+            xfce_warn (_("Only %s space left on %s (%s)!"),
+                       msg_size, fsguard->path, fsguard->name);
+        } else {
+            xfce_warn (_("Only %s space left on %s!"),
+                       msg_size, fsguard->path);
+        }
+    }
 
     return TRUE;
 }
@@ -292,13 +333,18 @@ fsguard_read_config (FsGuard *fsguard)
 
     fsguard->seen               = FALSE;
     fsguard->name               = g_strdup (xfce_rc_read_entry (rc, "label", ""));
+    fsguard->show_name          = xfce_rc_read_bool_entry (rc, "label_visible", FALSE);
     fsguard->path               = g_strdup (xfce_rc_read_entry (rc, "mnt", "/"));
-    fsguard->filemanager        = g_strdup (xfce_rc_read_entry (rc, "filemanager", "Thunar"));
     fsguard->show_size          = xfce_rc_read_bool_entry (rc, "lab_size_visible", TRUE);
     fsguard->show_progress_bar  = xfce_rc_read_bool_entry (rc, "progress_bar_visible", TRUE);
     fsguard->hide_button        = xfce_rc_read_bool_entry (rc, "hide_button", FALSE);
-    fsguard->limit_warning      = xfce_rc_read_int_entry (rc, "yellow", 1500);
-    fsguard->limit_urgent       = xfce_rc_read_int_entry (rc, "red", 300);
+    fsguard->limit_warning      = xfce_rc_read_int_entry (rc, "yellow", 8);
+    fsguard->limit_urgent       = xfce_rc_read_int_entry (rc, "red", 2);
+    /* Prevent MB values from earlier configuration files (2009-08-14) */
+    if (fsguard->limit_warning > 100)
+      fsguard->limit_warning = 8;
+    if (fsguard->limit_urgent > 100)
+      fsguard->limit_urgent = 2;
 
     xfce_rc_close (rc);
 }
@@ -320,8 +366,8 @@ fsguard_write_config (XfcePanelPlugin *plugin, FsGuard *fsguard)
     xfce_rc_write_bool_entry (rc, "progress_bar_visible", fsguard->show_progress_bar);
     xfce_rc_write_bool_entry (rc, "hide_button", fsguard->hide_button);
     xfce_rc_write_entry (rc, "label", fsguard->name);
+    xfce_rc_write_bool_entry (rc, "label_visible", fsguard->show_name);
     xfce_rc_write_entry (rc, "mnt", fsguard->path);
-    xfce_rc_write_entry (rc, "filemanager", fsguard->filemanager);
 
     xfce_rc_close (rc);
 }    
@@ -382,6 +428,7 @@ fsguard_new (XfcePanelPlugin *plugin)
     gtk_widget_set_size_request(fsguard->ebox, -1, -1);
     gtk_widget_show_all (fsguard->ebox);
     fsguard_refresh_name (fsguard);
+    fsguard_refresh_button (fsguard);
     if (fsguard->show_size != TRUE)
         gtk_widget_hide (fsguard->lab_size);
     if (fsguard->show_progress_bar != TRUE)
@@ -401,7 +448,6 @@ fsguard_free (XfcePanelPlugin *plugin, FsGuard *fsguard)
 
     g_free (fsguard->name);
     g_free (fsguard->path);
-    g_free (fsguard->filemanager);
 
     g_free(fsguard);
 }
@@ -449,13 +495,6 @@ fsguard_entry1_changed (GtkWidget *widget, FsGuard *fsguard)
     fsguard_check_fs (fsguard);
 }
 
-static void
-fsguard_entry2_changed (GtkWidget *widget, FsGuard *fsguard)
-{
-    g_free (fsguard->filemanager);
-    fsguard->filemanager = g_strdup (gtk_entry_get_text (GTK_ENTRY(widget)));
-}
-
 static void
 fsguard_spin1_changed (GtkWidget *widget, FsGuard *fsguard)
 {
@@ -471,6 +510,13 @@ fsguard_spin2_changed (GtkWidget *widget, FsGuard *fsguard)
     fsguard_check_fs (fsguard);
 }
 
+static void
+fsguard_check1_changed (GtkWidget *widget, FsGuard *fsguard)
+{
+    fsguard->show_name = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(widget));
+    fsguard_refresh_name (fsguard);
+}
+
 static void
 fsguard_entry3_changed (GtkWidget *widget, FsGuard *fsguard)
 {
@@ -480,7 +526,7 @@ fsguard_entry3_changed (GtkWidget *widget, FsGuard *fsguard)
 }
 
 static void
-fsguard_check1_changed (GtkWidget *widget, FsGuard *fsguard)
+fsguard_check2_changed (GtkWidget *widget, FsGuard *fsguard)
 {
     fsguard->show_size = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(widget));
     if (fsguard->show_size)
@@ -492,7 +538,7 @@ fsguard_check1_changed (GtkWidget *widget, FsGuard *fsguard)
 }
 
 static void
-fsguard_check2_changed (GtkWidget *widget, FsGuard *fsguard)
+fsguard_check3_changed (GtkWidget *widget, FsGuard *fsguard)
 {
     fsguard->show_progress_bar = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(widget));
     if (fsguard->show_progress_bar)
@@ -504,9 +550,9 @@ fsguard_check2_changed (GtkWidget *widget, FsGuard *fsguard)
 }
 
 static void
-fsguard_check3_changed (GtkWidget *widget, FsGuard *fsguard)
+fsguard_check4_changed (GtkWidget *widget, FsGuard *fsguard)
 {
-    fsguard->hide_button = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(widget));
+    fsguard->hide_button = !gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(widget));
 
     if (fsguard->hide_button == FALSE)
         gtk_widget_show (fsguard->btn_panel);
@@ -530,10 +576,10 @@ fsguard_create_options (XfcePanelPlugin *plugin, FsGuard *fsguard)
         NULL);
     gtk_window_set_icon_name (GTK_WINDOW (dialog), "xfce4-fsguard-plugin-warning");
     gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-    gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), BORDER);
+    gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
 
     /* Configuration frame */
-    GtkWidget *table1 = gtk_table_new (2, 4, FALSE);
+    GtkWidget *table1 = gtk_table_new (2, 3, FALSE);
     GtkWidget *frame1 = xfce_create_framebox_with_content (_("Configuration"), table1);
     gtk_table_set_row_spacings (GTK_TABLE (table1), BORDER);
     gtk_table_set_col_spacings (GTK_TABLE (table1), BORDER);
@@ -547,38 +593,28 @@ fsguard_create_options (XfcePanelPlugin *plugin, FsGuard *fsguard)
     gtk_entry_set_max_length (GTK_ENTRY (entry1), 32);
     gtk_entry_set_text (GTK_ENTRY (entry1), fsguard->path);
 
-    GtkWidget *label2 = gtk_label_new (_("File manager"));
-    gtk_misc_set_alignment (GTK_MISC (label2), 0, 0.5);
-    GtkWidget *entry2 = gtk_entry_new ();
-    gtk_entry_set_max_length (GTK_ENTRY (entry2), 16);
-    gtk_entry_set_text (GTK_ENTRY (entry2), fsguard->filemanager);
-
-    GtkWidget *label3 = gtk_label_new (_("Warning limit (MB)"));
+    GtkWidget *label3 = gtk_label_new (_("Warning limit (%)"));
     gtk_misc_set_alignment (GTK_MISC (label3), 0, 0.5);
-    GtkWidget *spin1 = gtk_spin_button_new_with_range (0, G_MAXUINT, 100);
+    GtkWidget *spin1 = gtk_spin_button_new_with_range (0, 100, 1);
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (spin1), fsguard->limit_warning);
 
-    GtkWidget *label4 = gtk_label_new (_("Urgent limit (MB)"));
+    GtkWidget *label4 = gtk_label_new (_("Urgent limit (%)"));
     gtk_misc_set_alignment (GTK_MISC (label4), 0, 0.5);
-    GtkWidget *spin2 = gtk_spin_button_new_with_range (0, G_MAXUINT, 100);
+    GtkWidget *spin2 = gtk_spin_button_new_with_range (0, 100, 1);
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (spin2), fsguard->limit_urgent);
 
     gtk_table_attach_defaults (GTK_TABLE (table1), label1,
                                0, 1, 0, 1);
     gtk_table_attach_defaults (GTK_TABLE (table1), entry1,
                                1, 2, 0, 1);
-    gtk_table_attach_defaults (GTK_TABLE (table1), label2,
-                               0, 1, 1, 2);
-    gtk_table_attach_defaults (GTK_TABLE (table1), entry2,
-                               1, 2, 1, 2);
     gtk_table_attach_defaults (GTK_TABLE (table1), label3,
-                               0, 1, 2, 3);
+                               0, 1, 1, 2);
     gtk_table_attach_defaults (GTK_TABLE (table1), spin1,
-                               1, 2, 2, 3);
+                               1, 2, 1, 2);
     gtk_table_attach_defaults (GTK_TABLE (table1), label4,
-                               0, 1, 3, 4);
+                               0, 1, 2, 3);
     gtk_table_attach_defaults (GTK_TABLE (table1), spin2,
-                               1, 2, 3, 4);
+                               1, 2, 2, 3);
 
     /* Display frame */
     GtkWidget *table2 = gtk_table_new (2, 4, FALSE);
@@ -589,31 +625,33 @@ fsguard_create_options (XfcePanelPlugin *plugin, FsGuard *fsguard)
     gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), frame2,
                         TRUE, TRUE, 0);
 
-    GtkWidget *label5 = gtk_label_new (_("Name"));
-    gtk_misc_set_alignment (GTK_MISC (label5), 0, 0.5);
+    GtkWidget *check1 = gtk_check_button_new_with_label (_("Name"));
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check1),
+                                  fsguard->show_name);
     GtkWidget *entry3 = gtk_entry_new ();
     gtk_entry_set_max_length (GTK_ENTRY (entry3), 16);
     gtk_entry_set_text (GTK_ENTRY (entry3), fsguard->name);
 
-    GtkWidget *check1 = gtk_check_button_new_with_label (_("Display size"));
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check1),
+
+    GtkWidget *check2 = gtk_check_button_new_with_label (_("Display size"));
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check2),
                                   fsguard->show_size);
 
-    GtkWidget *check2 = gtk_check_button_new_with_label (_("Display meter"));
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check2),
+    GtkWidget *check3 = gtk_check_button_new_with_label (_("Display meter"));
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check3),
                                   fsguard->show_progress_bar);
 
-    fsguard->cb_hide_button = gtk_check_button_new_with_label (_("Hide button"));
+    fsguard->cb_hide_button = gtk_check_button_new_with_label (_("Display button"));
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (fsguard->cb_hide_button),
-                                  fsguard->hide_button);
+                                  !fsguard->hide_button);
 
-    gtk_table_attach_defaults (GTK_TABLE (table2), label5,
+    gtk_table_attach_defaults (GTK_TABLE (table2), check1,
                                0, 1, 0, 1);
     gtk_table_attach_defaults (GTK_TABLE (table2), entry3,
                                1, 2, 0, 1);
-    gtk_table_attach_defaults (GTK_TABLE (table2), check1,
-                               0, 2, 1, 2);
     gtk_table_attach_defaults (GTK_TABLE (table2), check2,
+                               0, 2, 1, 2);
+    gtk_table_attach_defaults (GTK_TABLE (table2), check3,
                                0, 2, 2, 3);
     gtk_table_attach_defaults (GTK_TABLE (table2), fsguard->cb_hide_button,
                                0, 2, 3, 4);
@@ -622,10 +660,6 @@ fsguard_create_options (XfcePanelPlugin *plugin, FsGuard *fsguard)
                       "changed",
                       G_CALLBACK (fsguard_entry1_changed),
                       fsguard);
-    g_signal_connect (entry2,
-                      "changed",
-                      G_CALLBACK (fsguard_entry2_changed),
-                      fsguard);
     g_signal_connect (spin1,
                       "value-changed",
                       G_CALLBACK (fsguard_spin1_changed),
@@ -634,22 +668,26 @@ fsguard_create_options (XfcePanelPlugin *plugin, FsGuard *fsguard)
                       "value-changed",
                       G_CALLBACK (fsguard_spin2_changed),
                       fsguard);
-    g_signal_connect (entry3,
-                      "changed",
-                      G_CALLBACK (fsguard_entry3_changed),
-                      fsguard);
     g_signal_connect (check1,
                       "toggled",
                       G_CALLBACK (fsguard_check1_changed),
                       fsguard);
+    g_signal_connect (entry3,
+                      "changed",
+                      G_CALLBACK (fsguard_entry3_changed),
+                      fsguard);
     g_signal_connect (check2,
                       "toggled",
                       G_CALLBACK (fsguard_check2_changed),
                       fsguard);
-    g_signal_connect (fsguard->cb_hide_button,
+    g_signal_connect (check3,
                       "toggled",
                       G_CALLBACK (fsguard_check3_changed),
                       fsguard);
+    g_signal_connect (fsguard->cb_hide_button,
+                      "toggled",
+                      G_CALLBACK (fsguard_check4_changed),
+                      fsguard);
 
     gtk_widget_show_all (GTK_DIALOG (dialog)->vbox);
     gtk_dialog_run (GTK_DIALOG (dialog));
